@@ -1,5 +1,5 @@
 /* xargs -- build and execute command lines from standard input
-   Copyright (C) 1990, 91, 92, 93, 94, 2000, 2003, 2005 Free Software Foundation, Inc.
+   Copyright (C) 1990, 91, 92, 93, 94, 2000, 2003, 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -133,8 +133,6 @@ extern int errno;
 /* Return nonzero if S is the EOF string.  */
 #define EOF_STR(s) (eof_str && *eof_str == *s && !strcmp (eof_str, s))
 
-extern char **environ;
-
 /* Do multibyte processing if multibyte characters are supported,
    unless multibyte sequences are search safe.  Multibyte sequences
    are search safe if searching for a substring using the byte
@@ -170,6 +168,7 @@ typedef int boolean;
 
 #include <xalloc.h>
 #include "closeout.h"
+#include "gnulib-version.h"
 
 void error PARAMS ((int status, int errnum, char *message,...));
 
@@ -271,7 +270,6 @@ static void add_proc PARAMS ((pid_t pid));
 static void wait_for_proc PARAMS ((boolean all));
 static void wait_for_proc_all PARAMS ((void));
 static long parse_num PARAMS ((char *str, int option, long min, long max, int fatal));
-static size_t env_size PARAMS ((char **envp));
 static void usage PARAMS ((FILE * stream));
 
 
@@ -345,8 +343,6 @@ get_char_oct_or_hex_escape(const char *s)
 static char 
 get_input_delimiter(const char *s)
 {
-  char result = '\0';
-  
   if (1 == strlen(s))
     {
       return s[0];
@@ -407,7 +403,6 @@ main (int argc, char **argv)
   int show_limits = 0;			/* --show-limits */
   int always_run_command = 1;
   char *input_file = "-"; /* "-" is stdin */
-  size_t size_of_environment = env_size(environ);
   char *default_cmd = "/bin/echo";
   int (*read_args) PARAMS ((void)) = read_line;
   void (*act_on_init_result)(void) = noop;
@@ -578,6 +573,7 @@ main (int argc, char **argv)
 
 	case 'v':
 	  printf (_("GNU xargs version %s\n"), version_string);
+	  printf (_("Built using GNU gnulib version %s\n"), gnulib_version);
 	  return 0;
 
 	default:
@@ -1213,17 +1209,6 @@ parse_num (char *str, int option, long int min, long int max, int fatal)
 
 /* Return how much of ARG_MAX is used by the environment.  */
 
-static size_t
-env_size (char **envp)
-{
-  size_t len = 0u;
-
-  while (*envp)
-    len += strlen (*envp++) + 1;
-
-  return len;
-}
-
 static void
 usage (FILE *stream)
 {
@@ -1234,7 +1219,7 @@ Usage: %s [-0prtx] [--interactive] [--null] [-d|--delimiter=delim]\n\
        [-I replace-str] [-i[replace-str]] [--replace[=replace-str]]\n\
        [-n max-args] [--max-args=max-args]\n\
        [-s max-chars] [--max-chars=max-chars]\n\
-       [-P max-procs]  [--max-procs=max-procs] [[--show-limits]\n\
+       [-P max-procs]  [--max-procs=max-procs] [--show-limits]\n\
        [--verbose] [--exit] [--no-run-if-empty] [--arg-file=file]\n\
        [--version] [--help] [command [initial-arguments]]\n"),
 	   program_name);
